using System.ComponentModel;
using System.Runtime.CompilerServices;
using System.Windows.Input;
using Microsoft.Maui.Controls;
using RobobinApp.Views;
using Shiny.BluetoothLE;

namespace RobobinApp.ViewModels

{
    //https://docs.ros.org/en/jazzy/Concepts/Intermediate/About-Domain-ID.html <- Should just work once wifi connection
    public class MainPageViewModel : INotifyPropertyChanged
    {
        private bool _isBusy;
        private string _statusMessage;
   
        public ICommand ConnectToRobobinCommand { get; }

        public MainPageViewModel()
        {

            ConnectToRobobinCommand = new Command(async () => await OnConnectToRobobin());
        }

        public bool IsBusy
        {
            get => _isBusy;
            set
            {
                _isBusy = value;
                OnPropertyChanged();
            }
        }

        public string StatusMessage
        {
            get => _statusMessage;
            set
            {
                _statusMessage = value;
                OnPropertyChanged();
            }
        }

        private async Task OnConnectToRobobin()
        {
            try
            {
                IsBusy = true;


				var connectionPage = new ConnectionPage
				{
					BindingContext = new ConnectionPageViewModel()
				};
				await Application.Current.MainPage.Navigation.PushAsync(connectionPage);
			}
            catch (Exception ex)
            {
                StatusMessage = $"Failed to connect: {ex.Message}";
                await Application.Current.MainPage.DisplayAlert("Error", StatusMessage, "OK");
            }
            finally
            {
                IsBusy = false;
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        protected void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
